@@ -29,24 +29,28 @@
 #' print(details)
 #' }
 ge_details <- function(.data, env, gen, resp){
-  factors  <- .data %>%
-    select(ENV = {{env}},
-           GEN = {{gen}}) %>%
+  factors  <-
+    .data %>%
+    select({{env}}, {{gen}}) %>%
     mutate_all(as.factor)
   vars <- .data %>% select({{resp}}, -names(factors))
-  has_text_in_num(vars)
   vars %<>% select_numeric_cols()
+  factors %<>% set_names("ENV", "GEN")
   listres <- list()
   nvar <- ncol(vars)
   for (var in 1:nvar) {
     data <- factors %>%
       mutate(Y = vars[[var]])
-    env_data <- means_by(data, {{env}}) %>%
+    if(has_na(data)){
+      data <- remove_rows_na(data)
+      has_text_in_num(data)
+    }
+    env_data <- means_by(data, ENV, na.rm = TRUE) %>%
       add_cols(TYPE = "Env") %>%
-      rename(CODE = {{env}})
-    gen_data <- means_by(data, {{gen}}) %>%
+      rename(CODE = "ENV")
+    gen_data <- means_by(data, GEN, na.rm = TRUE) %>%
       add_cols(TYPE = "Gen")%>%
-      rename(CODE = {{gen}})
+      rename(CODE = "GEN")
     df_bind <-
       rbind(env_data, gen_data) %>%
       column_to_first(TYPE, CODE)
@@ -66,12 +70,12 @@ ge_details <- function(.data, env, gen, resp){
       as.data.frame()
     min <- data %>% top_n(1, -Y) %>% select(ENV, GEN, Y) %>% slice(1)
     max <- data %>% top_n(1, Y) %>% select(ENV, GEN, Y) %>% slice(1)
-    desc_st <- desc_stat(data, stats = c("mean, se, sd.pop, cv"), verbose = FALSE)
+    desc_st <- desc_stat(data, stats = c("mean, se, sd.pop, cv"), verbose = FALSE, na.rm = TRUE)
     temp <- tibble(Parameters = c("Mean", "SE", "SD", "CV", "Min", "Max", "MinENV", "MaxENV", "MinGEN", "MaxGEN"),
                    Values = c(round(desc_st[1, 2], 2),
-                              round(desc_st[2, 2], 2),
-                              round(desc_st[3, 2], 2),
-                              round(desc_st[4, 2], 2),
+                              round(desc_st[1, 3], 2),
+                              round(desc_st[1, 4], 2),
+                              round(desc_st[1, 5], 2),
                               paste0(round(min[3], 2), " (", min$GEN, " in ", min$ENV,")"),
                               paste0(round(max$Y, 2), " (", max$GEN, " in ", max$ENV,")"),
                               paste0(min_group[1,2], " (", round(min_group[1,3], 2),")"),
